@@ -12,7 +12,7 @@ def install(package: str, check=True):
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
     subprocess.check_call([sys.executable, "-m", "pip", "install", "--upgrade", package])
     if check:
-        print(f"Библиотека {package} установлена.")
+        print(f"Library {package} installed.")
 
 
 def pip_upgrade():
@@ -21,10 +21,10 @@ def pip_upgrade():
 
 def required():
     install("python-time", check=False)
-    require = ["requests", "opencv-python", "progress", "dearpygui"]
-    print("Установка необходимых библиотек...")
+    require = ["requests", "ipython", "progress", "dearpygui"]
+    print("Installing the required libraries...")
     for i in range(len(require)):
         install(require[i])
         print(f"Status: {i + 1} of {len(require)}")
-    print("Установка завершена.")
-    time.sleep(1)
+        time.sleep(1)
+    print("Installation is complete.")
